You are viewing a plain text version of this content. The canonical link for it is here.
Posted to xap-commits@incubator.apache.org by mt...@apache.org on 2006/07/15 17:22:44 UTC

svn commit: r422273 [1/5] - in /incubator/xap/trunk: WebContent/examples/dojo/ src/xap/ src/xap/bridges/basic/ src/xap/bridges/dojo/ src/xap/bridges/google/ src/xap/bridges/zimbra/ src/xap/components/zimbra/ src/xap/macro/ src/xap/mco/ src/xap/requests...

Author: mturyn
Date: Sat Jul 15 10:22:41 2006
New Revision: 422273

URL: http://svn.apache.org/viewvc?rev=422273&view=rev
Log:
All objects except the extensions/revisions of Zimbra classes* should
now be properly scoped within the scheme we've devised, with a
toplevel object "xap" and otherwise following the directory structure.
A lone exception is the Xap object itself, which is confusing given
that there's a "xap" object as well, so maybe we'll end up identifying
the two.

To this end, all files (except Zimbroid ones) are now loaded using
dojo.require(), as wrapped within Xap.require() so that we can
potentially do things like turning on Dojo's debugging switches, which
last will take more work.  Files must now also use dojo.provide() (via
Xap.provide()) let the Dojo loader know what's being loaded, which in
turn creates the objects scoping our classes, e.g. "xap.xml.dom".

HOW-TO:
All this was done with extensive use of regular expressions, first to
assemble a list of files that contained unscoped constructor
definitions ("^[A-Z].*= *function.*="), using that to construct a
mapping /x/y/z/Foo.js-->(Foo, x.y.z.Foo) and then going through all
the files (using *ix shells' "find" or Windows' "for /r in (*.js) do
") and implementing all those mappings using "sed".

A lot of work is required afterward, but this creates a first draft
with a lower error-rate than (my) doing it by hand, and has the
advantage of being re-runnable if there's a foul-up later.


*Anything starting with "Ajx", or with "Dwt" and doesn't end with "Bridge".

Modified:
    incubator/xap/trunk/WebContent/examples/dojo/dojo1.html
    incubator/xap/trunk/src/xap/Xap.js
    incubator/xap/trunk/src/xap/bridges/basic/TextViewBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/DojoContentPaneBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutContainerBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutPaneBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/DojoSplitPaneBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleIconBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleIconsBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleInfoWindowBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleMapBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleMarkerBridge.js
    incubator/xap/trunk/src/xap/bridges/google/GoogleMarkersBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtButtonBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtCompositeBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtControlBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitChildBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitterBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtTextFieldBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeItemBridge.js
    incubator/xap/trunk/src/xap/bridges/zimbra/DwtVerticalLayoutPanelBridge.js
    incubator/xap/trunk/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js
    incubator/xap/trunk/src/xap/components/zimbra/DwtSplitChild.js
    incubator/xap/trunk/src/xap/components/zimbra/DwtSplitter.js
    incubator/xap/trunk/src/xap/components/zimbra/DwtTablePanel.js
    incubator/xap/trunk/src/xap/components/zimbra/DwtVerticalLayoutPanel.js
    incubator/xap/trunk/src/xap/macro/Macro.js
    incubator/xap/trunk/src/xap/macro/MacroNamespaceHandler.js
    incubator/xap/trunk/src/xap/mco/McoInvocationException.js
    incubator/xap/trunk/src/xap/mco/McoInvocationExceptionRes.js
    incubator/xap/trunk/src/xap/mco/McoNamespaceHandler.js
    incubator/xap/trunk/src/xap/requestservice/NetServiceListener.js
    incubator/xap/trunk/src/xap/requestservice/RequestService.js
    incubator/xap/trunk/src/xap/session/ClientEvent.js
    incubator/xap/trunk/src/xap/session/ClientSession.js
    incubator/xap/trunk/src/xap/session/Container.js
    incubator/xap/trunk/src/xap/session/DeclarativeArgumentParser.js
    incubator/xap/trunk/src/xap/session/EventHandler.js
    incubator/xap/trunk/src/xap/taghandling/PluginDocumentHandler.js
    incubator/xap/trunk/src/xap/taghandling/PluginRegistry.js
    incubator/xap/trunk/src/xap/taghandling/PluginRegistryImpl.js
    incubator/xap/trunk/src/xap/util/Hashtable.js
    incubator/xap/trunk/src/xap/util/HttpUtils.js
    incubator/xap/trunk/src/xap/util/LogFactory.js
    incubator/xap/trunk/src/xap/util/Profiler.js
    incubator/xap/trunk/src/xap/util/ResourceDictionary.js
    incubator/xap/trunk/src/xap/util/UidProvider.js
    incubator/xap/trunk/src/xap/util/Utils.js
    incubator/xap/trunk/src/xap/util/XapException.js
    incubator/xap/trunk/src/xap/util/XmlUtils.js
    incubator/xap/trunk/src/xap/xml/DocumentContainer.js
    incubator/xap/trunk/src/xap/xml/InvalidXmlException.js
    incubator/xap/trunk/src/xap/xml/InvalidXmlExceptionRes.js
    incubator/xap/trunk/src/xap/xml/NamespaceHandler.js
    incubator/xap/trunk/src/xap/xml/NamespaceHandlerManager.js
    incubator/xap/trunk/src/xap/xml/XalNamespaceHandler.js
    incubator/xap/trunk/src/xap/xml/dom/Document.js
    incubator/xap/trunk/src/xap/xml/dom/XapElement.js
    incubator/xap/trunk/src/xap/xml/dom/XapElementRes.js
    incubator/xap/trunk/src/xap/xml/dom/events/AttributeChangeEvent.js
    incubator/xap/trunk/src/xap/xml/dom/events/AttributeChangeListener.js
    incubator/xap/trunk/src/xap/xml/dom/events/ChangeRejectedException.js
    incubator/xap/trunk/src/xap/xml/dom/events/ChangeRejectedExceptionRes.js
    incubator/xap/trunk/src/xap/xml/dom/events/DocumentOwnershipListener.js
    incubator/xap/trunk/src/xap/xml/dom/events/DomChangeEvent.js
    incubator/xap/trunk/src/xap/xml/dom/events/StructureChangeEvent.js
    incubator/xap/trunk/src/xap/xml/dom/events/StructureChangeListener.js
    incubator/xap/trunk/src/xap/xml/sax/EmptyDocumentException.js
    incubator/xap/trunk/src/xap/xml/sax/EmptyDocumentExceptionRes.js
    incubator/xap/trunk/src/xap/xml/sax/ParserException.js
    incubator/xap/trunk/src/xap/xml/sax/ParserExceptionRes.js
    incubator/xap/trunk/src/xap/xml/sax/SaxContentHandler.js
    incubator/xap/trunk/src/xap/xml/sax/SaxParser.js
    incubator/xap/trunk/src/xap/xml/xmodify/CommandDirective.js
    incubator/xap/trunk/src/xap/xml/xmodify/DirectiveSet.js
    incubator/xap/trunk/src/xap/xml/xmodify/UpdateDirective.js
    incubator/xap/trunk/src/xap/xml/xmodify/Xmodify.js
    incubator/xap/trunk/src/xap/xml/xmodify/XmodifyException.js
    incubator/xap/trunk/src/xap/xml/xmodify/XmodifyNamespaceHandler.js

Modified: incubator/xap/trunk/WebContent/examples/dojo/dojo1.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/dojo1.html?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/dojo1.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/dojo1.html Sat Jul 15 10:22:41 2006
@@ -46,7 +46,7 @@
 	<h1>Xaplet embedded in a table cell:</h1>
 	
 	<table id="bigtable" border="4px" borderColor="#8866AA" width="80%" height="80%"
-		style="left:"10%";top:"10%";opacity:"80%"
+		style="left:10%;top:10%;opacity:80%"
 		cellpadding="20em" cellspacing="2px"
 		>
 		<tr><th width="30%">0.</th><th>1.</th></tr>

Modified: incubator/xap/trunk/src/xap/Xap.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/Xap.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/Xap.js (original)
+++ incubator/xap/trunk/src/xap/Xap.js Sat Jul 15 10:22:41 2006
@@ -15,9 +15,6 @@
  *
  */
  
- idxx=-1 ;
- 
-
 Xap = function () {}
 
 //make xap load from the xap directory
@@ -59,7 +56,7 @@
 	var currentContext =   new google.ExprContext(document) ;
 // The following _should_ work, but I think google's XPath
 // is a little broken---an earlier attempt to run //*[id='anId']
-// in Xmodify code didn't work, either	
+// in xap.xml.xmodify.Xmodify code didn't work, either	
 //	var parsedXPathExpr = google.xpathParse("//*[@appName]") ;
 	var parsedXPathExpr = google.xpathParse("//") ;
 	var targetNodes = parsedXPathExpr.evaluate( currentContext );
@@ -116,7 +113,9 @@
 	Xap._debugLoad = (loadType)?true:false ;
 
 	Xap._logString = "" ;
-	
+	Xap._showLog = function(){
+		prompt("",Xap._logString.replace(/\n/g,"^")) ;
+	} 	
 
 	Xap._sourceRootDir = sourceRootDir;
 	Xap.loadXap( sourceRootDir );
@@ -124,7 +123,7 @@
 }
 
 Xap.createSession = function( context, startPage,toolkitType , element) {
-	var session = new ClientSession( context,toolkitType ,element );
+	var session = new xap.session.ClientSession( context,toolkitType ,element );
 	session._start( startPage );
 	return session;
 }
@@ -223,126 +222,126 @@
 //of these files, it gives an error on this.func being undefined.
 //That's ok as we are going to ditch these files anyway
 Xap.loadZimbra = function( sourceRootDir ) {
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/msgs/AjxMsg.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxCore.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxEnv.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxUtil.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxText.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxException.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxCookie.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/soap/AjxSoapException.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/soap/AjxSoapFault.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/soap/AjxSoapDoc.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/net/AjxRpcRequest.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/net/AjxRpc.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxWindowOpener.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxVector.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxStringUtils.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/debug/AjxDebug.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/debug/AjxDebugXmlDocument.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/xml/AjxXmlDoc.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/config/data/AjxConfig.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxEnv.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxImg.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxException.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxCallback.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxTimedAction.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/events/AjxEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/events/AjxEventMgr.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/events/AjxListener.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxDateUtils.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxStringUtils.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxVector.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxSelectionManager.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/net/AjxPost.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxBuffer.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxCache.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/msgs/AjxMsg.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxCore.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxEnv.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxUtil.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxText.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxException.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxCookie.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/soap/AjxSoapException.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/soap/AjxSoapFault.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/soap/AjxSoapDoc.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/net/AjxRpcRequest.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/net/AjxRpc.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxWindowOpener.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxVector.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxStringUtils.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/debug/AjxDebug.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/debug/AjxDebugXmlDocument.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/xml/AjxXmlDoc.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/config/data/AjxConfig.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxEnv.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxImg.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/core/AjxException.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxCallback.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxTimedAction.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/events/AjxEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/events/AjxEventMgr.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/events/AjxListener.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxDateUtils.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxStringUtils.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxVector.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxSelectionManager.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/net/AjxPost.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxBuffer.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/util/AjxCache.js" );
 	
 	// DWT classes
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/DwtImg.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/DwtImg.js" );
 	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/Dwt.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/DwtException.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/DwtDraggable.js" );
-	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtCssStyle.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtPoint.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtRectangle.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtUnits.js" );
-	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtEventManager.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtDateRangeEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtDisposeEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtUiEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtControlEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtKeyEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtMouseEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtMouseEventCapture.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtListViewActionEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtSelectionEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtHtmlEditorStateEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtTreeEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtHoverEvent.js" );
-	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDragEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDragSource.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDropEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDropTarget.js" );
-	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtHoverMgr.js" );
-	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtControl.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtComposite.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtShell.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtColorPicker.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtBaseDialog.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtDialog.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtLabel.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtListView.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtButton.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtMenuItem.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtMenu.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtMessageDialog.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtHtmlEditor.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtInputField.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtSash.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtToolBar.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtBorder.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtToolTip.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtStickyToolTip.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtTreeItem.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtTree.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtCalendar.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtPropertyPage.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtTabView.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtWizardDialog.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtSelect.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtAddRemove.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtAlert.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtText.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtIframe.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtXFormDialog.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtPropertySheet.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtGrouper.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtProgressBar.js" );
-	
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtXFormsEvent.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XFormGlobal.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XModel.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XModelItem.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XForm.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XFormItem.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XFormChoices.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/OSelect_XFormItem.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/ButtonGrid.js" );
-	Utils.importFile(  sourceRootDir + "/src/zimbra/examples/tree/TreeExample.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/Dwt.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/DwtException.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/core/DwtDraggable.js" );
+	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtCssStyle.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtPoint.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtRectangle.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtUnits.js" );
+	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtEventManager.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtDateRangeEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtDisposeEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtUiEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtControlEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtKeyEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtMouseEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtMouseEventCapture.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtListViewActionEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtSelectionEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtHtmlEditorStateEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtTreeEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtHoverEvent.js" );
+	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDragEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDragSource.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDropEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/dnd/DwtDropTarget.js" );
+	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtHoverMgr.js" );
+	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtControl.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtComposite.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtShell.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtColorPicker.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtBaseDialog.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtDialog.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtLabel.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtListView.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtButton.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtMenuItem.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtMenu.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtMessageDialog.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtHtmlEditor.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtInputField.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtSash.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtToolBar.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/graphics/DwtBorder.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtToolTip.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtStickyToolTip.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtTreeItem.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtTree.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtCalendar.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtPropertyPage.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtTabView.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtWizardDialog.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtSelect.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtAddRemove.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtAlert.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtText.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtIframe.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtXFormDialog.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtPropertySheet.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtGrouper.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/widgets/DwtProgressBar.js" );
+	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/events/DwtXFormsEvent.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XFormGlobal.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XModel.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XModelItem.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XForm.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XFormItem.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/XFormChoices.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/OSelect_XFormItem.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/js/dwt/xforms/ButtonGrid.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/zimbra/examples/tree/TreeExample.js" );
 	
 	//TODO this really shouldn't be here, but they rely on some zimbra stuff
 	//and are zimbra extensions
-	Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtSplitter.js" );
-	Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtSplitChild.js" );
-	Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtTablePanel.js" );
-	Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtVerticalLayoutPanel.js" );	
-	Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js" );	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtSplitter.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtSplitChild.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtTablePanel.js" );
+	xap.util.Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtVerticalLayoutPanel.js" );	
+	xap.util.Utils.importFile(  sourceRootDir + "/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js" );	
 }

Modified: incubator/xap/trunk/src/xap/bridges/basic/TextViewBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/basic/TextViewBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtButtonBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtButtonBridge.js Sat Jul 15 10:22:41 2006
@@ -16,6 +16,7 @@
  */
  
 Xap.provide("xap.bridges.zimbra.DwtButtonBridge"); 
+Xap.require("xap.bridges.zimbra.DwtControlBridge"); 
  /**
  * @fileoverview
  * 

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtCompositeBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtCompositeBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtCompositeBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtCompositeBridge.js Sat Jul 15 10:22:41 2006
@@ -48,33 +48,34 @@
 xap.bridges.zimbra.DwtCompositeBridge.prototype = new xap.bridges.zimbra.DwtControlBridge;
 xap.bridges.zimbra.DwtCompositeBridge.s_log = xap.util.LogFactory.getLog("xap.bridges.zimbra.DwtCompositeBridge");
 
-with (xap.bridges.zimbra.DwtCompositeBridge.prototype) {
-    xap.bridges.zimbra.DwtCompositeBridge.prototype.toString = function () {
-        return "xap.bridges.zimbra.DwtCompositeBridge";
-    };
-    /**
+
+xap.bridges.zimbra.DwtCompositeBridge.prototype.toString = function () {
+    return "xap.bridges.zimbra.DwtCompositeBridge";
+};
+
+/**
  * Creates the peer component that this bridge controls.
  */
-    createPeer = function () {
-        var parent = this.getElement().getParent();
-        var handler = this.getUiContentHandler().getHandlerForElement(parent);
-        var parentPeer = handler.getPeer();
-        if (parentPeer instanceof DwtComposite) {
-            var peer = new DwtComposite(parentPeer, null, DwtControl.ABSOLUTE_STYLE, null);
-            this.setPeer(peer);
-        } else {
-            xap.bridges.zimbra.DwtCompositeBridge.s_log.error("Bogus parent peer:" + parentPeer);
-        }
-    };
-    onChildRemoved = function (e) {
-	//if the element being removed maps to a DwtControl then
-	//remove it from ourselves
-        var handler = this.getUiContentHandler().getHandlerForElement(e.getChange());
-        if (handler && handler.getPeer() instanceof DwtControl) {
-            this.getPeer().removeChild(handler.getPeer());
-        }
-        xap.bridges.zimbra.DwtControlBridge.prototype.onChildRemoved.call(this, e);
-    };
-}
+xap.bridges.zimbra.DwtCompositeBridge.prototype.createPeer = function () {
+    var parent = this.getElement().getParent();
+    var handler = this.getUiContentHandler().getHandlerForElement(parent);
+    var parentPeer = handler.getPeer();
+    if (parentPeer instanceof DwtComposite) {
+        var peer = new DwtComposite(parentPeer, null, DwtControl.ABSOLUTE_STYLE, null);
+        this.setPeer(peer);
+    } else {
+        xap.bridges.zimbra.DwtCompositeBridge.s_log.error("Bogus parent peer:" + parentPeer);
+    }
+};
+xap.bridges.zimbra.DwtCompositeBridge.prototype.onChildRemoved = function (e) {
+//if the element being removed maps to a DwtControl then
+//remove it from ourselves
+    var handler = this.getUiContentHandler().getHandlerForElement(e.getChange());
+    if (handler && handler.getPeer() instanceof DwtControl) {
+        this.getPeer().removeChild(handler.getPeer());
+    }
+    xap.bridges.zimbra.DwtControlBridge.prototype.onChildRemoved.call(this, e);
+};
+
 
 

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtControlBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtControlBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtControlBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtControlBridge.js Sat Jul 15 10:22:41 2006
@@ -35,10 +35,10 @@
  * @author jmargaris
  */
 xap.bridges.zimbra.DwtControlBridge = function() {
-	AbstractTagImpl.call( this );
+	xap.taghandling.AbstractTagImpl.call( this );
 }
 
-xap.bridges.zimbra.DwtControlBridge.prototype = new AbstractTagImpl;
+xap.bridges.zimbra.DwtControlBridge.prototype = new xap.taghandling.AbstractTagImpl;
 
 xap.bridges.zimbra.DwtControlBridge.s_log = xap.util.LogFactory.getLog( "DwtControlBridge" );
 
@@ -69,7 +69,7 @@
 	this.createPeer();
 	this.parseInitialAttributes( this.getElement() );
 	this.parseInitialChildren( this.getElement() );
-	AbstractTagImpl.prototype.init.call( this );
+	xap.taghandling.AbstractTagImpl.prototype.init.call( this );
 	this.getPeer().zShow( true );
 }
 
@@ -193,7 +193,7 @@
 		peer.getHtmlElement().style.textAlign=value;
 	}
 	else{
-		AbstractTagImpl.prototype.attributeSet.call( this, event );
+		xap.taghandling.AbstractTagImpl.prototype.attributeSet.call( this, event );
 	}
 	
 }

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitChildBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitChildBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitChildBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitChildBridge.js Sat Jul 15 10:22:41 2006
@@ -19,14 +19,14 @@
  /**
  * @fileoverview
  * 
- * A bridge class that controls an DwtSplitChild peer.
+ * A bridge class that controls a DwtSplitChild peer.
  */
  
 /**
- * Creates a DwtSplitChildBridge.
+ * Creates a xap.bridges.zimbra.DwtSplitChildBridge.
  * 
  * 
- * @class DwtSplitChildBridge is the bridge between an XML element
+ * @class xap.bridges.zimbra.DwtSplitChildBridge is the bridge between an XML element
  * representing a child of a splitter and an DwtSplitChild. A splitter
  * has one split child in the left/top and one in the right/bottom.
  * 
@@ -38,7 +38,7 @@
 
 xap.bridges.zimbra.DwtSplitChildBridge.prototype = new xap.bridges.zimbra.DwtCompositeBridge;
 
-xap.bridges.zimbra.DwtSplitChildBridge.s_log = xap.util.LogFactory.getLog( "DwtSplitChildBridge" );
+xap.bridges.zimbra.DwtSplitChildBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.zimbra.DwtSplitChildBridge" );
 
 xap.bridges.zimbra.DwtSplitChildBridge.prototype.toString = function() {
 	return "xap.bridges.zimbra.DwtSplitChildBridge";

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitterBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitterBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitterBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtSplitterBridge.js Sat Jul 15 10:22:41 2006
@@ -23,11 +23,11 @@
  */
  
 /**
- * Creates a DwtSplitterBridge.
+ * Creates a xap.bridges.zimbra.DwtSplitterBridge.
  * 
  * 
- * @class DwtSplitterBridge is the bridge between an XML element
- * representing a splitter and an DwtSplitter. A splitter
+ * @class xap.bridges.zimbra.DwtSplitterBridge is the bridge between an XML element
+ * representing a splitter and an xap.bridges.zimbra.DwtSplitter. A splitter
  * has one split child in the left/top and one in the right/bottom.
  * 
  * @author jmargaris
@@ -38,7 +38,7 @@
 
 xap.bridges.zimbra.DwtSplitterBridge.prototype = new xap.bridges.zimbra.DwtCompositeBridge;
 
-xap.bridges.zimbra.DwtSplitterBridge.s_log = xap.util.LogFactory.getLog( "DwtSplitterBridge" );
+xap.bridges.zimbra.DwtSplitterBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.zimbra.DwtSplitterBridge" );
 
 xap.bridges.zimbra.DwtSplitterBridge.prototype.toString = function() {
 	return "xap.bridges.zimbra.DwtSplitterBridge";
@@ -68,7 +68,7 @@
 /**
  * This method is called whenever an attribute
  * on the XML element that maps to this bridge class
- * is changed. DwtSplitterBridge handles the following attributes:
+ * is changed. xap.bridges.zimbra.DwtSplitterBridge handles the following attributes:
  * <ul>
  * <li>splitPosition - the position of the splitter, does not work for
  * percentages at this point.</li>

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtTextFieldBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtTextFieldBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtTextFieldBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtTextFieldBridge.js Sat Jul 15 10:22:41 2006
@@ -101,7 +101,7 @@
  */
 xap.bridges.zimbra.DwtTextFieldBridge.prototype._validatorFunction = function( text ) {
 	this.writeBackAttribute("text", text);
-	var clientEvent = new ClientEvent(this.getElement(), this.getSession());
+	var clientEvent = new xap.session.ClientEvent(this.getElement(), this.getSession());
 	clientEvent.text = text;
 	this.fireEvent("onEdit", null, null, clientEvent);
 }

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeBridge.js Sat Jul 15 10:22:41 2006
@@ -50,7 +50,7 @@
     var handler = this.getUiContentHandler().getHandlerForPeer(item);
    
 
-    var clientEvent = new ClientEvent(this.getElement(), this.getSession());
+    var clientEvent = new xap.session.ClientEvent(this.getElement(), this.getSession());
     
     var detail = event.detail;
     
@@ -77,7 +77,7 @@
     var handler = this.getUiContentHandler().getHandlerForPeer(item);
    
 
-    var clientEvent = new ClientEvent(this.getElement(), this.getSession());
+    var clientEvent = new xap.session.ClientEvent(this.getElement(), this.getSession());
     
     var detail = event.detail;
     
@@ -122,11 +122,11 @@
  * Subclasses should override this method to handle dynamic removal of children.
  * Subclasses must either call super.onChildRemoved() or invoke
  * afterChildRemoved() directly.
- * @param e The StructureChangeEvent
+ * @param e The xap.xml.dom.events.StructureChangeEvent
  */
 xap.bridges.zimbra.DwtTreeBridge.prototype.onChildRemoved = function( event ) {
 	
-	if ( event.getType() == StructureChangeEvent.ELEMENT_NODE ) {    
+	if ( event.getType() == xap.xml.dom.events.StructureChangeEvent.ELEMENT_NODE ) {    
 	    //get the peer for the client and ask it to handle this.
         var handler = this.getUiContentHandler().getHandlerForElement(event.getChange());
         this.getPeer().removeChild(handler.getPeer());

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeItemBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeItemBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeItemBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtTreeItemBridge.js Sat Jul 15 10:22:41 2006
@@ -75,11 +75,11 @@
  * Subclasses should override this method to handle dynamic removal of children.
  * Subclasses must either call super.onChildRemoved() or invoke
  * afterChildRemoved() directly.
- * @param e The StructureChangeEvent
+ * @param e The xap.xml.dom.events.StructureChangeEvent
  */
 xap.bridges.zimbra.DwtTreeItemBridge.prototype.onChildRemoved = function( event ) {
 	
-	if ( event.getType() == StructureChangeEvent.ELEMENT_NODE ) {    
+	if ( event.getType() == xap.xml.dom.events.StructureChangeEvent.ELEMENT_NODE ) {    
 	    //get the peer for the client and ask it to handle this.
         var handler = this.getUiContentHandler().getHandlerForElement(event.getChange());
         this.getPeer().removeChild(handler.getPeer());

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtVerticalLayoutPanelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtVerticalLayoutPanelBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/zimbra/DwtVerticalLayoutPanelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/zimbra/DwtVerticalLayoutPanelBridge.js Sat Jul 15 10:22:41 2006
@@ -37,7 +37,7 @@
 
 xap.bridges.zimbra.DwtVerticalLayoutPanelBridge.prototype = new xap.bridges.zimbra.DwtCompositeBridge;
 
-xap.bridges.zimbra.DwtVerticalLayoutPanelBridge.s_log = xap.util.LogFactory.getLog( "DwtVerticalLayoutPanelBridge" );
+xap.bridges.zimbra.DwtVerticalLayoutPanelBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.zimbra.DwtVerticalLayoutPanelBridge" );
 
 
 xap.bridges.zimbra.DwtVerticalLayoutPanelBridge.prototype.toString = function() {

Modified: incubator/xap/trunk/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js (original)
+++ incubator/xap/trunk/src/xap/components/zimbra/DwtHorizontalLayoutPanel.js Sat Jul 15 10:22:41 2006
@@ -29,6 +29,9 @@
  * 
  * @author jmargaris
  */
+
+//Xap.provide("xap.components.zimbra.DwtHorizontalLayoutPanel") ;
+ 
 DwtHorizontalLayoutPanel = function(parent, style, className, posStyle) {
 	DwtTablePanel.call(this, parent, style, className, posStyle);
 }

Modified: incubator/xap/trunk/src/xap/components/zimbra/DwtSplitChild.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/components/zimbra/DwtSplitChild.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/components/zimbra/DwtSplitChild.js (original)
+++ incubator/xap/trunk/src/xap/components/zimbra/DwtSplitChild.js Sat Jul 15 10:22:41 2006
@@ -32,6 +32,9 @@
  * 
  * @author jmargaris
  */
+ 
+// Xap.provide("DwtSplitChild") ;
+ 
 DwtSplitChild = function(parent, isLeftTop) {
 	this._isLeftTop = isLeftTop;
 	DwtComposite.call(this, parent, null, DwtControl.ABSOLUTE_STYLE);	
@@ -58,4 +61,4 @@
 
 DwtSplitChild.prototype.isLeftTopChild = function() {
 	return this._isLeftTop;
-}
\ No newline at end of file
+}

Modified: incubator/xap/trunk/src/xap/components/zimbra/DwtSplitter.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/components/zimbra/DwtSplitter.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/components/zimbra/DwtSplitter.js (original)
+++ incubator/xap/trunk/src/xap/components/zimbra/DwtSplitter.js Sat Jul 15 10:22:41 2006
@@ -14,7 +14,7 @@
  *  limitations under the License.
  *
  */
- 
+ //Xap.provide("xap.components.zimbra.DwtSplitter") ;
  /**
  * @fileoverview
  * 

Modified: incubator/xap/trunk/src/xap/components/zimbra/DwtTablePanel.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/components/zimbra/DwtTablePanel.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/components/zimbra/DwtTablePanel.js (original)
+++ incubator/xap/trunk/src/xap/components/zimbra/DwtTablePanel.js Sat Jul 15 10:22:41 2006
@@ -14,6 +14,8 @@
  *  limitations under the License.
  *
  */
+ //Xap.provide("xap.components.zimbra.DwtTablePanel") ;
+ 
  
  /**
  * @fileoverview

Modified: incubator/xap/trunk/src/xap/components/zimbra/DwtVerticalLayoutPanel.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/components/zimbra/DwtVerticalLayoutPanel.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/components/zimbra/DwtVerticalLayoutPanel.js (original)
+++ incubator/xap/trunk/src/xap/components/zimbra/DwtVerticalLayoutPanel.js Sat Jul 15 10:22:41 2006
@@ -15,6 +15,9 @@
  *
  */
  
+ //Xap.provide("xap.components.zimbra.DwtVerticalLayoutPanel") ;
+ 
+ 
  /**
  * @fileoverview
  * 

Modified: incubator/xap/trunk/src/xap/macro/Macro.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/macro/Macro.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/basic/TextViewBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/basic/TextViewBridge.js Sat Jul 15 10:22:41 2006
@@ -23,26 +23,26 @@
  */
 
 /**
- * Creates a TextViewBridge.
+ * Creates a xap.bridges.basic.TextViewBridge.
  * 
  * 
  * @class TextViewBridge is the bridge between an XML element
  * representing a blob of html.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-TextViewBridge = function() {
-	AbstractTagImpl.call( this );
+xap.bridges.basic.TextViewBridge = function() {
+	xap.taghandling.AbstractTagImpl.call( this );
 }
 
-TextViewBridge.prototype = new AbstractTagImpl;
+xap.bridges.basic.TextViewBridge.prototype = new xap.taghandling.AbstractTagImpl;
 
-TextViewBridge.s_log = xap.util.LogFactory.getLog( "TextViewBridge" );
+xap.bridges.basic.TextViewBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.basic.TextViewBridge" );
 
-TextViewBridge.prototype.toString = function() {
-	return "TextViewBridge";
+xap.bridges.basic.TextViewBridge.prototype.toString = function() {
+	return "xap.bridges.basic.TextViewBridge";
 }
 
 /**
@@ -63,17 +63,17 @@
  * One effect of this is that instead of hooking up the hierarchy 
  * from tail to head we do it from head to tail.
  */
-TextViewBridge.prototype.init = function() {
+xap.bridges.basic.TextViewBridge.prototype.init = function() {
 	this.createPeer();
 	this.parseInitialAttributes( this.getElement() );
 	this.parseInitialChildren( this.getElement() );
-	AbstractTagImpl.prototype.init.call( this );
+	xap.taghandling.AbstractTagImpl.prototype.init.call( this );
 }
 
 /**
  * Creates the peer component that this bridge controls.
  */
-TextViewBridge.prototype.createPeer = function() {
+xap.bridges.basic.TextViewBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -86,7 +86,7 @@
         	alert(e);
     	}
 	} else {
-		DwtButtonBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.zimbra.DwtButtonBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -23,26 +23,26 @@
  * 
  * 
- * @class TextViewBridge is the bridge between an XML element
+ * @class xap.bridges.basic.TextViewBridge is the bridge between an XML element
  * representing a blob of html.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoContentPaneBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoContentPaneBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoContentPaneBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoContentPaneBridge.js Sat Jul 15 10:22:41 2006
@@ -24,10 +24,10 @@
  */
 
 /**
- * Creates a DojoContentPaneBridge.
+ * Creates a xap.bridges.dojo.DojoContentPaneBridge.
  * 
  * 
  * @class DojoContentPaneBridge is the bridge between an XML element
  * representing a button and the DojoContentPane Zimbra class.
  * 
  * @author jmargaris
@@ -43,26 +43,26 @@
  * A bridge class with dojo contentPane peer.
  */
  
-DojoContentPaneBridge = function() {
-	DojoWidgetBridge.call(this);
+xap.bridges.dojo.DojoContentPaneBridge = function() {
+	xap.bridges.dojo.DojoWidgetBridge.call(this);
 }
 
-DojoContentPaneBridge.prototype = new DojoWidgetBridge;
+xap.bridges.dojo.DojoContentPaneBridge.prototype = new xap.bridges.dojo.DojoWidgetBridge;
 
 
-DojoContentPaneBridge.prototype.constructor=DojoContentPaneBridge ;
+xap.bridges.dojo.DojoContentPaneBridge.prototype.constructor=xap.bridges.dojo.DojoContentPaneBridge ;
 
-DojoContentPaneBridge.s_log = xap.util.LogFactory.getLog( "DojoContentPaneBridge" );
+xap.bridges.dojo.DojoContentPaneBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.dojo.DojoContentPaneBridge" );
 
-DojoContentPaneBridge.prototype.toString = function() {
-	return "DojoContentPaneBridge";
+xap.bridges.dojo.DojoContentPaneBridge.prototype.toString = function() {
+	return "xap.bridges.dojo.DojoContentPaneBridge";
 }
 
 /**
  * Provides the name used to create the peer component
  * that this bridge controls.
  */
-DojoContentPaneBridge.prototype.getPeerString = function(){
+xap.bridges.dojo.DojoContentPaneBridge.prototype.getPeerString = function(){
     return "ContentPane" ;
 }
  
@@ -80,7 +80,7 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-DojoContentPaneBridge.prototype.attributeSet = function( event ) {
+xap.bridges.dojo.DojoContentPaneBridge.prototype.attributeSet = function( event ) {
     var name = event.getName();
     var value = event.getNewValue();
     var peer = this.getPeer();
@@ -94,7 +94,7 @@
           }
     }
     else{
-        DojoWidgetBridge.prototype.attributeSet.call( this, event );
+        xap.bridges.dojo.DojoWidgetBridge.prototype.attributeSet.call( this, event );
     }
 
 }
@@ -24,10 +24,10 @@
  * 
  * 
- * @class DojoContentPaneBridge is the bridge between an XML element
+ * @class xap.bridges.dojo.DojoContentPaneBridge is the bridge between an XML element
  * representing a button and the DojoContentPane Zimbra class.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutContainerBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutContainerBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutContainerBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutContainerBridge.js Sat Jul 15 10:22:41 2006
@@ -22,10 +22,10 @@
  */
 
 /**
- * Creates a DojoLayoutContainerBridge.
+ * Creates a xap.bridges.dojo.DojoLayoutContainerBridge.
  * 
  * 
  * @class DojoLayoutContainerBridge is the bridge between an XML element
  * representing a button and the Dojo LayoutContainer class.
  * 
  * @author jmargarisz
@@ -42,24 +42,24 @@
  * A bridge class with dojo toolkit button peer.
  */
  
-DojoLayoutContainerBridge= function() {
-	DojoWidgetBridge.call(this);
+xap.bridges.dojo.DojoLayoutContainerBridge= function() {
+	xap.bridges.dojo.DojoWidgetBridge.call(this);
 }
 
-DojoLayoutContainerBridge.prototype = new DojoWidgetBridge;
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype = new xap.bridges.dojo.DojoWidgetBridge;
 
 
-DojoLayoutContainerBridge.prototype.constructor=DojoLayoutContainerBridge ;
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype.constructor=xap.bridges.dojo.DojoLayoutContainerBridge ;
 
-DojoLayoutContainerBridge.s_log = xap.util.LogFactory.getLog( "DojoLayoutContainerBridge" );
+xap.bridges.dojo.DojoLayoutContainerBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.dojo.DojoLayoutContainerBridge" );
 
-DojoLayoutContainerBridge.prototype.toString = function() {
-	return "DojoLayoutContainerBridge";
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype.toString = function() {
+	return "xap.bridges.dojo.DojoLayoutContainerBridge";
 }
 
 
 
-DojoLayoutContainerBridge.prototype.getPeerString = function(){
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype.getPeerString = function(){
     return "LayoutContainer" ;
 }
 
@@ -67,7 +67,7 @@
  * This is a container, not a widget, so it doesn't use createWidget
  * Need to give the new layout an empsty array of children.
  */
-DojoLayoutContainerBridge.prototype.createPeer = function() {
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -86,7 +86,7 @@
 		this.setPeer( peer );
 		//peer.addSelectionListener(new AjxListener(this, this._onSelectEvent));
 	} else {
-		DojoWidgetBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.dojo.DojoWidgetBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -95,7 +95,7 @@
  * The callback for the selection listener on DojoLayoutContainer.
  * When this is called we fire an "onCommand" event.
  */
-DojoLayoutContainerBridge.prototype._onSelectEvent = function( event ) {
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype._onSelectEvent = function( event ) {
 	this.fireEvent("onCommand");
 }
 
@@ -111,7 +111,7 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-DojoLayoutContainerBridge.prototype.attributeSet = function( event ) {
+xap.bridges.dojo.DojoLayoutContainerBridge.prototype.attributeSet = function( event ) {
     var name = event.getName();
     var value = event.getNewValue();
     var peer = this.getPeer();
@@ -123,7 +123,7 @@
     	peer.layoutAlign = value ;
     } 
     else {
-        DojoWidgetBridge.prototype.attributeSet.call( this, event );
+        xap.bridges.dojo.DojoWidgetBridge.prototype.attributeSet.call( this, event );
     }
     peer.onResized() ;
 }
@@ -22,10 +22,10 @@
  * 
  * 
- * @class DojoLayoutContainerBridge is the bridge between an XML element
+ * @class xap.bridges.dojo.DojoLayoutContainerBridge is the bridge between an XML element
  * representing a button and the Dojo LayoutContainer class.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutPaneBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutPaneBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutPaneBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoLayoutPaneBridge.js Sat Jul 15 10:22:41 2006
@@ -22,10 +22,10 @@
  */
 
 /**
- * Creates a DojoLayoutPaneBridge.
+ * Creates a xap.bridges.dojo.DojoLayoutPaneBridge.
  * 
  * 
  * @class DojoLayoutPaneBridge is the bridge between an XML element
  * representing a button and the Dojo LayoutPane class.
  * 
  * @author jmargarisz
@@ -42,24 +42,24 @@
  * A bridge class with dojo toolkit button peer.
  */
  
-DojoLayoutPaneBridge= function() {
-	DojoWidgetBridge.call(this);
+xap.bridges.dojo.DojoLayoutPaneBridge= function() {
+	xap.bridges.dojo.DojoWidgetBridge.call(this);
 }
 
-DojoLayoutPaneBridge.prototype = new DojoWidgetBridge;
+xap.bridges.dojo.DojoLayoutPaneBridge.prototype = new xap.bridges.dojo.DojoWidgetBridge;
 
 
-DojoLayoutPaneBridge.prototype.constructor=DojoLayoutPaneBridge ;
+xap.bridges.dojo.DojoLayoutPaneBridge.prototype.constructor=xap.bridges.dojo.DojoLayoutPaneBridge ;
 
-DojoLayoutPaneBridge.s_log = xap.util.LogFactory.getLog( "DojoLayoutPaneBridge" );
+xap.bridges.dojo.DojoLayoutPaneBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.dojo.DojoLayoutPaneBridge" );
 
-DojoLayoutPaneBridge.prototype.toString = function() {
-	return "DojoLayoutPaneBridge";
+xap.bridges.dojo.DojoLayoutPaneBridge.prototype.toString = function() {
+	return "xap.bridges.dojo.DojoLayoutPaneBridge";
 }
 
 
 
-DojoLayoutPaneBridge.prototype.getPeerString = function(){
+xap.bridges.dojo.DojoLayoutPaneBridge.prototype.getPeerString = function(){
     return "LayoutPane" ;
 }
 
@@ -70,7 +70,7 @@
  * The callback for the selection listener on DojoLayoutPane.
  * When this is called we fire an "onCommand" event.
  */
-DojoLayoutPaneBridge.prototype._onSelectEvent = function( event ) {
+xap.bridges.dojo.DojoLayoutPaneBridge.prototype._onSelectEvent = function( event ) {
 	this.fireEvent("onCommand");
 }
 
@@ -86,7 +86,7 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-DojoLayoutPaneBridge.prototype.attributeSet = function( event ) {
+xap.bridges.dojo.DojoLayoutPaneBridge.prototype.attributeSet = function( event ) {
     var name = event.getName();
     var value = event.getNewValue();
     var peer = this.getPeer();
@@ -95,7 +95,7 @@
     	peer.layoutAlign = value ;
     } 
     else{
-        DojoWidgetBridge.prototype.attributeSet.call( this, event );
+        xap.bridges.dojo.DojoWidgetBridge.prototype.attributeSet.call( this, event );
     }
     peer.onResized() ;
 }
@@ -22,10 +22,10 @@
  * 
  * 
- * @class DojoLayoutPaneBridge is the bridge between an XML element
+ * @class xap.bridges.dojo.DojoLayoutPaneBridge is the bridge between an XML element
  * representing a button and the Dojo LayoutPane class.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoSplitPaneBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoSplitPaneBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoSplitPaneBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoSplitPaneBridge.js Sat Jul 15 10:22:41 2006
@@ -22,10 +22,10 @@
  */
 
 /**
- * Creates a DojoSplitPaneBridge.
+ * Creates a xap.bridges.dojo.DojoSplitPaneBridge.
  * 
  * 
  * @class DojoSplitPaneBridge is the bridge between an XML element
  * representing a button and the Dojo SplitPane class.
  * 
  * @author jmargaris
@@ -42,16 +42,16 @@
  * DojoSplitPane instances and handled directly 
  * by this bridge, not a superclass.
 **/ 
-DojoSplitPaneBridge._propertyMap = {"orientation":true, "sizerWidth":true, "activeSizing":true, 
+xap.bridges.dojo.DojoSplitPaneBridge._propertyMap = {"orientation":true, "sizerWidth":true, "activeSizing":true, 
 									"sizeMin":true, "sizeShare":true} ;
 
 /**
  * isManagedProperty
  * @param propertyName Does a DojoSplitPaneBridge handle this property?
  * @return boolean
 **/ 
-DojoSplitPaneBridge.hasManagedPeerProperty = function(propertyName){
-	return (DojoSplitPaneBridge._propertyMap[propertyName]!= null) ;
+xap.bridges.dojo.DojoSplitPaneBridge.hasManagedPeerProperty = function(propertyName){
+	return (xap.bridges.dojo.DojoSplitPaneBridge._propertyMap[propertyName]!= null) ;
 }
  
  /**
@@ -60,24 +60,24 @@
  * A bridge class with dojo toolkit button peer.
  */
  
-DojoSplitPaneBridge= function() {
-	DojoPaneBridge.call(this);
+xap.bridges.dojo.DojoSplitPaneBridge= function() {
+	xap.bridges.dojo.DojoPaneBridge.call(this);
 }
 
-DojoSplitPaneBridge.prototype = new DojoPaneBridge;
+xap.bridges.dojo.DojoSplitPaneBridge.prototype = new xap.bridges.dojo.DojoPaneBridge;
 
 
-DojoSplitPaneBridge.prototype.constructor=DojoSplitPaneBridge ;
+xap.bridges.dojo.DojoSplitPaneBridge.prototype.constructor=xap.bridges.dojo.DojoSplitPaneBridge ;
 
-DojoSplitPaneBridge.s_log = xap.util.LogFactory.getLog( "DojoSplitPaneBridge" );
+xap.bridges.dojo.DojoSplitPaneBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.dojo.DojoSplitPaneBridge" );
 
-DojoSplitPaneBridge.prototype.toString = function() {
-	return "DojoSplitPaneBridge";
+xap.bridges.dojo.DojoSplitPaneBridge.prototype.toString = function() {
+	return "xap.bridges.dojo.DojoSplitPaneBridge";
 }
 
 
 
-DojoSplitPaneBridge.prototype.getPeerString = function(){
+xap.bridges.dojo.DojoSplitPaneBridge.prototype.getPeerString = function(){
     return "SplitPane" ;
 }
 
@@ -96,17 +96,17 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-DojoSplitPaneBridge.prototype.attributeSet = function( event ) {
+xap.bridges.dojo.DojoSplitPaneBridge.prototype.attributeSet = function( event ) {
     var name = event.getName();
     var value = event.getNewValue();
     var peer = this.getPeer();
     
-    if ( DojoSplitPaneBridge.hasManagedPeerProperty(name) ){
+    if ( xap.bridges.dojo.DojoSplitPaneBridge.hasManagedPeerProperty(name) ){
     	//Simple
     	peer[name] = value ;
     }    
     else{
-        DojoPaneBridge.prototype.attributeSet.call( this, event );
+        xap.bridges.dojo.DojoPaneBridge.prototype.attributeSet.call( this, event );
     }
     peer.onResized() ;
 }
@@ -22,10 +22,10 @@
  * 
  * 
- * @class DojoSplitPaneBridge is the bridge between an XML element
+ * @class xap.bridges.dojo.DojoSplitPaneBridge is the bridge between an XML element
  * representing a button and the Dojo SplitPane class.
  * 
@@ -42,16 +42,16 @@
 /**
  * isManagedProperty
- * @param propertyName Does a DojoSplitPaneBridge handle this property?
+ * @param propertyName Does a xap.bridges.dojo.DojoSplitPaneBridge handle this property?
  * @return boolean
 **/ 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js Sat Jul 15 10:22:41 2006
@@ -38,10 +38,10 @@
  * @author mturyn
  */
 xap.bridges.dojo.DojoWidgetBridge =  function() {
-	AbstractTagImpl.call( this );
+	xap.taghandling.AbstractTagImpl.call( this );
 }
 
-xap.bridges.dojo.DojoWidgetBridge.prototype = new AbstractTagImpl;
+xap.bridges.dojo.DojoWidgetBridge.prototype = new xap.taghandling.AbstractTagImpl;
 
 xap.bridges.dojo.DojoWidgetBridge.prototype.constructor = xap.bridges.dojo.DojoWidgetBridge ;
 
@@ -64,7 +64,7 @@
 	this.createPeer();
 	this.parseInitialAttributes( this.getElement() );
 	this.parseInitialChildren( this.getElement() );
-	AbstractTagImpl.prototype.init.call( this );
+	xap.taghandling.AbstractTagImpl.prototype.init.call( this );
 	this.getPeer().show();
 }
 
@@ -94,7 +94,7 @@
  * Is the property in the list of allowed ones?
  */
 xap.bridges.dojo.DojoWidgetBridge.prototype.allowsInitialProperty = function(prop){
-	return Utils.doesArrayContain(this.getAllowedInitialProperties(),prop) ;
+	return xap.util.Utils.doesArrayContain(this.getAllowedInitialProperties(),prop) ;
 }
 
 /**
@@ -159,12 +159,12 @@
 		delete propertyMap.dojoType ;		
 
 		if (dojoType == null ){
 		// Make this a XapException once we're stable:
 			throw new Exception("No dojo type specified by class or passed-in map.") ;		
    		}
    
    		// The candy in the middle of the wrapper:
-   		//Utils.interrogate(propertyMap) ;
+   		//xap.util.Utils.interrogate(propertyMap) ;
         var peer = dojo.widget.createWidget(dojoType,propertyMap,tmp);
    
 		this.setPeer( peer );
@@ -289,7 +289,7 @@
         peer.domNode.style.textAlign=value;
     }    
 	else{
-		AbstractTagImpl.prototype.attributeSet.call( this, event );
+		xap.taghandling.AbstractTagImpl.prototype.attributeSet.call( this, event );
         return ;
 	}
     
@@ -159,12 +159,12 @@
 
 		if (dojoType == null ){
-		// Make this a XapException once we're stable:
+		// Make this a xap.util.XapException once we're stable:
 			throw new Exception("No dojo type specified by class or passed-in map.") ;		
    		}

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleBridge.js Sat Jul 15 10:22:41 2006
@@ -24,26 +24,26 @@
  */
 
 /**
- * Creates a GoogleBridge.
+ * Creates a xap.bridges.google.GoogleBridge.
  * 
  * 
  * @class GoogleBridge is the bridge between an XML element
  * representing a google object.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleBridge = function() {
-	AbstractTagImpl.call( this );
+xap.bridges.google.GoogleBridge = function() {
+	xap.taghandling.AbstractTagImpl.call( this );
 }
 
-GoogleBridge.prototype = new AbstractTagImpl;
+xap.bridges.google.GoogleBridge.prototype = new xap.taghandling.AbstractTagImpl;
 
-GoogleBridge.s_log = xap.util.LogFactory.getLog( "GoogleBridge" );
+xap.bridges.google.GoogleBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleBridge" );
 
-GoogleBridge.prototype.toString = function() {
-	return "GoogleBridge";
+xap.bridges.google.GoogleBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleBridge";
 }
 
 /**
@@ -64,11 +64,11 @@
  * One effect of this is that instead of hooking up the hierarchy 
  * from tail to head we do it from head to tail.
  */
-GoogleBridge.prototype.init = function() {
+xap.bridges.google.GoogleBridge.prototype.init = function() {
 	this.createPeer();
 	this.parseInitialAttributes( this.getElement() );
 	this.parseInitialChildren( this.getElement() );
-	AbstractTagImpl.prototype.init.call( this );
+	xap.taghandling.AbstractTagImpl.prototype.init.call( this );
 }
 
 /**
@@ -77,7 +77,7 @@
  * takes a string that is comma seperated latitude and longitude "37.23232, -80.0000"
  * and returns a GLatLng object.  
  */
-GoogleBridge.prototype.convertStringToGLatLng = function(value) {
+xap.bridges.google.GoogleBridge.prototype.convertStringToGLatLng = function(value) {
     var lat = value.substring(0, value.indexOf(",")) * 1.0;
     var lng = value.substring(value.indexOf(",") + 1) * 1.0;
     return new GLatLng(lat, lng);   
@@ -87,7 +87,7 @@
  * takes a string that is comma seperated x and y "37, 80"
  * and returns a CPoint object.  
  */
-GoogleBridge.prototype.convertStringToGPoint = function(value) {
+xap.bridges.google.GoogleBridge.prototype.convertStringToGPoint = function(value) {
     var x = value.substring(0, value.indexOf(",")) * 1.0;
     var y = value.substring(value.indexOf(",") + 1) * 1.0;
     return new GPoint(x, y);   
@@ -97,11 +97,11 @@
  * takes a string that is comma seperated width and height "37, 80"
  * and returns a GSize object.  
  */
-GoogleBridge.prototype.convertStringToGSize = function(value) {
+xap.bridges.google.GoogleBridge.prototype.convertStringToGSize = function(value) {
     var width = value.substring(0, value.indexOf(",")) * 1.0;
     var height = value.substring(value.indexOf(",") + 1) * 1.0;
     return new GSize(width, height);   
 }
 
-GoogleBridge.prototype.handleRemoval = function(parent, parentPeer) {
+xap.bridges.google.GoogleBridge.prototype.handleRemoval = function(parent, parentPeer) {
 }
@@ -24,26 +24,26 @@
  * 
  * 
- * @class GoogleBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleBridge is the bridge between an XML element
  * representing a google object.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleIconBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleIconBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleIconBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleIconBridge.js Sat Jul 15 10:22:41 2006
@@ -26,32 +26,32 @@
 Xap.require("xap.bridges.google.GoogleBridge"); 
 
 /**
- * Creates a GoogleInfoWindowBridge.
+ * Creates a xap.bridges.google.GoogleInfoWindowBridge.
  * 
  * 
  * @class GoogleInfoWindowBridge is the bridge between an XML element
  * representing a google maps marker.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleIconBridge = function() {
-	GoogleBridge.call( this );
+xap.bridges.google.GoogleIconBridge = function() {
+	xap.bridges.google.GoogleBridge.call( this );
 }
 
-GoogleIconBridge.prototype = new GoogleBridge;
+xap.bridges.google.GoogleIconBridge.prototype = new xap.bridges.google.GoogleBridge;
 
-GoogleIconBridge.s_log = xap.util.LogFactory.getLog( "GoogleIconBridge" );
+xap.bridges.google.GoogleIconBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleIconBridge" );
 
-GoogleIconBridge.prototype.toString = function() {
-	return "GoogleIconBridge";
+xap.bridges.google.GoogleIconBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleIconBridge";
 }
 
 /**
  * Creates the peer component that this bridge controls.
  */
-GoogleIconBridge.prototype.createPeer = function() {
+xap.bridges.google.GoogleIconBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -92,7 +92,7 @@
         	alert(e);
     	}
 	} else {
-		GoogleIconBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.google.GoogleIconBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -100,9 +100,9 @@
  *    Handles the clicking of a marker. 
  * 
  */
-GoogleIconBridge.prototype.onMarkerClickEvent = function( marker ) {
+xap.bridges.google.GoogleIconBridge.prototype.onMarkerClickEvent = function( marker ) {
 	
-    var clientEvent = new ClientEvent(this.getElement(), this.getSession());
+    var clientEvent = new xap.session.ClientEvent(this.getElement(), this.getSession());
     var handler = this.getUiContentHandler().getHandlerForPeer(marker);
     
     clientEvent.marker = marker;
@@ -119,7 +119,7 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-GoogleIconBridge.prototype.attributeSet = function( event ) {
+xap.bridges.google.GoogleIconBridge.prototype.attributeSet = function( event ) {
 	var name = event.getName();
 	var value = event.getNewValue();
     
@@ -130,7 +130,7 @@
 	}else if (name=="iconAnchor"){
 	}else if (name=="infoWindowAnchor"){
 	}else{
-		GoogleBridge.prototype.attributeSet.call( this, event );
+		xap.bridges.google.GoogleBridge.prototype.attributeSet.call( this, event );
 	}
 	
 }
@@ -139,9 +139,9 @@
  * Called by the parent to handle the removal of the Xml Element from the parent.
  * In the case of the marker bridge we will need to remove the maker.
  */
-GoogleIconBridge.prototype.handleRemoval = function(parent, parentPeer) {
+xap.bridges.google.GoogleIconBridge.prototype.handleRemoval = function(parent, parentPeer) {
     //remove the marker.
     parentPeer.removeOverlay(this.getPeer());
 
-	GoogleBridge.prototype.attributeSet.call( this, event );
+	xap.bridges.google.GoogleBridge.prototype.attributeSet.call( this, event );
 }
@@ -26,32 +26,32 @@
  * 
  * 
- * @class GoogleInfoWindowBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleInfoWindowBridge is the bridge between an XML element
  * representing a google maps marker.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleIconsBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleIconsBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleIconsBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleIconsBridge.js Sat Jul 15 10:22:41 2006
@@ -25,29 +25,29 @@
 Xap.require("xap.bridges.google.GoogleBridge"); 
 
 /**
- * Creates a GoogleIconsBridge.
+ * Creates a xap.bridges.google.GoogleIconsBridge.
  * 
  * 
  * @class GoogleIconsBridge is the bridge between an XML element
  * representing a google object.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleIconsBridge = function() {
-	AbstractTagImpl.call( this );
+xap.bridges.google.GoogleIconsBridge = function() {
+	xap.taghandling.AbstractTagImpl.call( this );
 }
 
-GoogleIconsBridge.prototype = new GoogleBridge;
+xap.bridges.google.GoogleIconsBridge.prototype = new xap.bridges.google.GoogleBridge;
 
-GoogleIconsBridge.s_log = xap.util.LogFactory.getLog( "GoogleIconsBridge" );
+xap.bridges.google.GoogleIconsBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleIconsBridge" );
 
-GoogleIconsBridge.prototype.toString = function() {
-	return "GoogleIconsBridge";
+xap.bridges.google.GoogleIconsBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleIconsBridge";
 }
 
-GoogleIconsBridge.prototype.createPeer = function() {
+xap.bridges.google.GoogleIconsBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -56,6 +56,6 @@
 	if ( parentPeer instanceof GMap2 ) {         
     	this.setPeer(parentPeer);
  	} else {
-		GoogleIconsBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.google.GoogleIconsBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
@@ -25,29 +25,29 @@
  * 
  * 
- * @class GoogleIconsBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleIconsBridge is the bridge between an XML element
  * representing a google object.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleInfoWindowBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleInfoWindowBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleInfoWindowBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleInfoWindowBridge.js Sat Jul 15 10:22:41 2006
@@ -25,32 +25,32 @@
  */
 
 /**
- * Creates a GoogleInfoWindowBridge.
+ * Creates a xap.bridges.google.GoogleInfoWindowBridge.
  * 
  * 
  * @class GoogleInfoWindowBridge is the bridge between an XML element
  * representing a google maps info window.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleInfoWindowBridge = function() {
-	GoogleBridge.call( this );
+xap.bridges.google.GoogleInfoWindowBridge = function() {
+	xap.bridges.google.GoogleBridge.call( this );
 }
 
-GoogleInfoWindowBridge.prototype = new GoogleBridge;
+xap.bridges.google.GoogleInfoWindowBridge.prototype = new xap.bridges.google.GoogleBridge;
 
-GoogleInfoWindowBridge.s_log = xap.util.LogFactory.getLog( "GoogleInfoWindowBridge" );
+xap.bridges.google.GoogleInfoWindowBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleInfoWindowBridge" );
 
-GoogleInfoWindowBridge.prototype.toString = function() {
-	return "GoogleInfoWindowBridge";
+xap.bridges.google.GoogleInfoWindowBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleInfoWindowBridge";
 }
 
 /**
  * Creates the peer component that this bridge controls.
  */
-GoogleInfoWindowBridge.prototype.createPeer = function() {
+xap.bridges.google.GoogleInfoWindowBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -75,7 +75,7 @@
         	alert(e);
     	}
 	} else {
-		GoogleInfoWindowBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.google.GoogleInfoWindowBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -25,32 +25,32 @@
  * 
  * 
- * @class GoogleInfoWindowBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleInfoWindowBridge is the bridge between an XML element
  * representing a google maps info window.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleMapBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleMapBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleMapBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleMapBridge.js Sat Jul 15 10:22:41 2006
@@ -25,32 +25,32 @@
  */
 
 /**
- * Creates a GoogleMapBridge.
+ * Creates a xap.bridges.google.GoogleMapBridge.
  * 
  * 
  * @class GoogleMapBridge is the bridge between an XML element
  * representing a google map and GMap2 class.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleMapBridge = function() {
-	GoogleBridge.call( this );
+xap.bridges.google.GoogleMapBridge = function() {
+	xap.bridges.google.GoogleBridge.call( this );
 }
 
-GoogleMapBridge.prototype = new GoogleBridge;
+xap.bridges.google.GoogleMapBridge.prototype = new xap.bridges.google.GoogleBridge;
 
-GoogleMapBridge.s_log = xap.util.LogFactory.getLog( "GoogleMapBridge" );
+xap.bridges.google.GoogleMapBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleMapBridge" );
 
-GoogleMapBridge.prototype.toString = function() {
-	return "GoogleMapBridge";
+xap.bridges.google.GoogleMapBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleMapBridge";
 }
 
 /**
  * Creates the peer component that this bridge controls.
  */
-GoogleMapBridge.prototype.createPeer = function() {
+xap.bridges.google.GoogleMapBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -71,7 +71,7 @@
         	alert(e);
     	}
 	} else {
-		GoogleMapBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.google.GoogleMapBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -79,9 +79,9 @@
  *    Handles the clicking of a marker. 
  * 
  */
-GoogleMapBridge.prototype.onMapClickEvent = function( marker, point, map ) {
+xap.bridges.google.GoogleMapBridge.prototype.onMapClickEvent = function( marker, point, map ) {
 	
-    var clientEvent = new ClientEvent(this.getElement(), this.getSession());
+    var clientEvent = new xap.session.ClientEvent(this.getElement(), this.getSession());
     var mapHandler = this.getUiContentHandler().getHandlerForPeer(map);
 
     //add the marker if the user clicked on it if not do nothing.
@@ -110,7 +110,7 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-GoogleMapBridge.prototype.attributeSet = function( event ) {
+xap.bridges.google.GoogleMapBridge.prototype.attributeSet = function( event ) {
 	var name = event.getName();
 	var value = event.getNewValue();
     
@@ -143,6 +143,6 @@
             this.gMap.setMapType(G_HYBRID_MAP);      
         }
 	}else{
-		GoogleBridge.prototype.attributeSet.call( this, event );
+		xap.bridges.google.GoogleBridge.prototype.attributeSet.call( this, event );
 	}
 }
@@ -25,32 +25,32 @@
  * 
  * 
- * @class GoogleMapBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleMapBridge is the bridge between an XML element
  * representing a google map and GMap2 class.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleMarkerBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleMarkerBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleMarkerBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleMarkerBridge.js Sat Jul 15 10:22:41 2006
@@ -25,32 +25,32 @@
  */
 
 /**
- * Creates a GoogleInfoWindowBridge.
+ * Creates a xap.bridges.google.GoogleInfoWindowBridge.
  * 
  * 
  * @class GoogleInfoWindowBridge is the bridge between an XML element
  * representing a google maps marker.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleMarkerBridge = function() {
-	GoogleBridge.call( this );
+xap.bridges.google.GoogleMarkerBridge = function() {
+	xap.bridges.google.GoogleBridge.call( this );
 }
 
-GoogleMarkerBridge.prototype = new GoogleBridge;
+xap.bridges.google.GoogleMarkerBridge.prototype = new xap.bridges.google.GoogleBridge;
 
-GoogleMarkerBridge.s_log = xap.util.LogFactory.getLog( "GoogleMarkerBridge" );
+xap.bridges.google.GoogleMarkerBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleMarkerBridge" );
 
-GoogleMarkerBridge.prototype.toString = function() {
-	return "GoogleMarkerBridge";
+xap.bridges.google.GoogleMarkerBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleMarkerBridge";
 }
 
 /**
  * Creates the peer component that this bridge controls.
  */
-GoogleMarkerBridge.prototype.createPeer = function() {
+xap.bridges.google.GoogleMarkerBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	parentPeer = handler.getPeer();
@@ -101,7 +101,7 @@
         	alert(e);
     	}
 	} else {
-		GoogleMarkerBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.google.GoogleMarkerBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -109,9 +109,9 @@
  *    Handles the clicking of a marker. 
  * 
  */
-GoogleMarkerBridge.prototype.onMarkerClickEvent = function( marker ) {
+xap.bridges.google.GoogleMarkerBridge.prototype.onMarkerClickEvent = function( marker ) {
 	
-    var clientEvent = new ClientEvent(this.getElement(), this.getSession());
+    var clientEvent = new xap.session.ClientEvent(this.getElement(), this.getSession());
     var handler = this.getUiContentHandler().getHandlerForPeer(marker);
     
     clientEvent.marker = marker;
@@ -128,7 +128,7 @@
  * Attributes not handled here are are passed to the 
  * superclass attributeSet method.
  */
-GoogleMarkerBridge.prototype.attributeSet = function( event ) {
+xap.bridges.google.GoogleMarkerBridge.prototype.attributeSet = function( event ) {
 	var name = event.getName();
 	var value = event.getNewValue();
     
@@ -137,7 +137,7 @@
 	}else if (name=="latitude"){	 
 	}else if (name=="longitude"){
 	}else{
-		GoogleBridge.prototype.attributeSet.call( this, event );
+		xap.bridges.google.GoogleBridge.prototype.attributeSet.call( this, event );
 	}
 	
 }
@@ -146,7 +146,7 @@
  * Called by the parent to handle the removal of the Xml Element from the parent.
  * In the case of the marker bridge we will need to remove the maker.
  */
-GoogleMarkerBridge.prototype.handleRemoval = function(parent, parentPeer) {
+xap.bridges.google.GoogleMarkerBridge.prototype.handleRemoval = function(parent, parentPeer) {
     //remove the marker.
     parentPeer.removeOverlay(this.getPeer());
 }
@@ -25,32 +25,32 @@
  * 
  * 
- * @class GoogleInfoWindowBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleInfoWindowBridge is the bridge between an XML element
  * representing a google maps marker.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/google/GoogleMarkersBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/google/GoogleMarkersBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/google/GoogleMarkersBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/google/GoogleMarkersBridge.js Sat Jul 15 10:22:41 2006
@@ -25,29 +25,29 @@
  */
 
 /**
- * Creates a GoogleMarkersBridge.
+ * Creates a xap.bridges.google.GoogleMarkersBridge.
  * 
  * 
  * @class GoogleMarkersBridge is the bridge between an XML element
  * representing a google object.
  * 
  * @constructor
  * 
  * @author bbuffone
  */
-GoogleMarkersBridge = function() {
-	AbstractTagImpl.call( this );
+xap.bridges.google.GoogleMarkersBridge = function() {
+	xap.taghandling.AbstractTagImpl.call( this );
 }
 
-GoogleMarkersBridge.prototype = new GoogleBridge;
+xap.bridges.google.GoogleMarkersBridge.prototype = new xap.bridges.google.GoogleBridge;
 
-GoogleMarkersBridge.s_log = xap.util.LogFactory.getLog( "GoogleMarkersBridge" );
+xap.bridges.google.GoogleMarkersBridge.s_log = xap.util.LogFactory.getLog( "xap.bridges.google.GoogleMarkersBridge" );
 
-GoogleMarkersBridge.prototype.toString = function() {
-	return "GoogleMarkersBridge";
+xap.bridges.google.GoogleMarkersBridge.prototype.toString = function() {
+	return "xap.bridges.google.GoogleMarkersBridge";
 }
 
-GoogleMarkersBridge.prototype.createPeer = function() {
+xap.bridges.google.GoogleMarkersBridge.prototype.createPeer = function() {
 	var parent = this.getElement().getParent();
 	var handler = this.getUiContentHandler().getHandlerForElement( parent );
 	var parentPeer = handler.getPeer();
@@ -56,7 +56,7 @@
 	if ( parentPeer instanceof GMap2 ) {         
     	this.setPeer(parentPeer);
  	} else {
-		GoogleMarkersBridge.s_log.error("Bogus parent peer:" + parentPeer );
+		xap.bridges.google.GoogleMarkersBridge.s_log.error("Bogus parent peer:" + parentPeer );
 	}
 }
 
@@ -64,15 +64,15 @@
  * Subclasses should override this method to handle dynamic removal of children.
  * Subclasses must either call super.onChildRemoved() or invoke
  * afterChildRemoved() directly.
- * @param e The StructureChangeEvent
+ * @param e The xap.xml.dom.events.StructureChangeEvent
  */
-GoogleMarkersBridge.prototype.onChildRemoved = function( event ) {
+xap.bridges.google.GoogleMarkersBridge.prototype.onChildRemoved = function( event ) {
 	
-	if ( event.getType() == StructureChangeEvent.ELEMENT_NODE ) {    
+	if ( event.getType() == xap.xml.dom.events.StructureChangeEvent.ELEMENT_NODE ) {    
 	    //get the peer for the client and ask it to handle this.
         var handler = this.getUiContentHandler().getHandlerForElement(event.getChange());
         handler.handleRemoval(this.getElement().getParent(), this.getPeer());
 	}
 	
-	GoogleBridge.prototype.onChildRemoved.call( this, event );
+	xap.bridges.google.GoogleBridge.prototype.onChildRemoved.call( this, event );
 }
@@ -25,29 +25,29 @@
  * 
  * 
- * @class GoogleMarkersBridge is the bridge between an XML element
+ * @class xap.bridges.google.GoogleMarkersBridge is the bridge between an XML element
  * representing a google object.
  * 

Modified: incubator/xap/trunk/src/xap/bridges/zimbra/DwtButtonBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/zimbra/DwtButtonBridge.js?rev=422273&r1=422272&r2=422273&view=diff
==============================================================================
--- incubator/xap/trunk/src/xap/macro/Macro.js (original)
+++ incubator/xap/trunk/src/xap/macro/Macro.js Sat Jul 15 10:22:41 2006
@@ -25,17 +25,17 @@
  
  
 /**
  * Creates a new Macro instance.
  * @param {String} macroText The content of the macro
  * @param {ClientSession} session The client session.
  * @constructor
 
  * @class A macro is a segment of stored xml that can be run oncommand as if 
  * it came from the server. Macros should support arguments via something
  * like java MessageFormat but these don't yet.
  * 
  */
-Macro = function( macroText, session ) {
+xap.macro.Macro = function( macroText, session ) {
 	this._macroText = macroText;
 	this._session = session;
 }
@@ -47,7 +47,7 @@
 //-----------------------------------------------------------------------
 // Public Methods.
 //-----------------------------------------------------------------------
-Macro.prototype.execute = function() {
+xap.macro.Macro.prototype.execute = function() {
 	
 	var finalText = this._macroText;
 	
@@ -60,7 +60,7 @@
 		finalText = xap.util.MessageFormat.format( this._macroText, args);
 	}
 	//TODO allow arguments that plug into message format style string
-	var parser = new SaxParser( new SaxContentHandler() );
+	var parser = new xap.xml.sax.SaxParser( new xap.xml.sax.SaxContentHandler() );
 	this._session.processDocument( parser.parse( finalText ) );
 }
 //Let Dojo know what to expect from this file:
@@ -25,17 +25,17 @@
  
 /**
- * Creates a new Macro instance.
+ * Creates a new xap.macro.Macro instance.
  * @param {String} macroText The content of the macro
@@ -25,17 +25,17 @@
  * @param {String} macroText The content of the macro
- * @param {ClientSession} session The client session.
+ * @param {xap.session.ClientSession} session The client session.
  * @constructor
 
@@ -25,17 +25,17 @@
 
  * @class A macro is a segment of stored xml that can be run oncommand as if 
- * it came from the server. Macros should support arguments via something
+ * it came from the server. xap.macro.Macros should support arguments via something
  * like java MessageFormat but these don't yet.
  * 